# ZUNI
ZUNI- Zillion Utility purpose Neural Interface

### How to install
The library can be easily installed using:
```bash
git clone git@github.com:ProjectSignal/ZUNI.git
cd ZUNI
python3 setup.py bdist_wheel
pip install .
```